# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TrafficLimitConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'qps': 'int',
        'per_source_ip_qps': 'int',
        'burst': 'int'
    }

    attribute_map = {
        'qps': 'qps',
        'per_source_ip_qps': 'per_source_ip_qps',
        'burst': 'burst'
    }

    def __init__(self, qps=None, per_source_ip_qps=None, burst=None):
        """TrafficLimitConfig

        The model defined in huaweicloud sdk

        :param qps: 转发策略整体限速。取值： 0-100000s。0表示不限速
        :type qps: int
        :param per_source_ip_qps: 对转发策略单源进行限速。 quic监听器下转发策略不支持配置单源限速，指定该字段时，赋值可以为0或者为null 取值： 0-100000s。0表示不限速，如果qps不为0，per_ip_qps需要小于qps。
        :type per_source_ip_qps: int
        :param burst: 对转发策略单源进行限速。取值： 0-100000s。当qps超限的时候，不返回503，支持允许局部突增burst大小的请求。
        :type burst: int
        """
        
        

        self._qps = None
        self._per_source_ip_qps = None
        self._burst = None
        self.discriminator = None

        if qps is not None:
            self.qps = qps
        if per_source_ip_qps is not None:
            self.per_source_ip_qps = per_source_ip_qps
        if burst is not None:
            self.burst = burst

    @property
    def qps(self):
        """Gets the qps of this TrafficLimitConfig.

        转发策略整体限速。取值： 0-100000s。0表示不限速

        :return: The qps of this TrafficLimitConfig.
        :rtype: int
        """
        return self._qps

    @qps.setter
    def qps(self, qps):
        """Sets the qps of this TrafficLimitConfig.

        转发策略整体限速。取值： 0-100000s。0表示不限速

        :param qps: The qps of this TrafficLimitConfig.
        :type qps: int
        """
        self._qps = qps

    @property
    def per_source_ip_qps(self):
        """Gets the per_source_ip_qps of this TrafficLimitConfig.

        对转发策略单源进行限速。 quic监听器下转发策略不支持配置单源限速，指定该字段时，赋值可以为0或者为null 取值： 0-100000s。0表示不限速，如果qps不为0，per_ip_qps需要小于qps。

        :return: The per_source_ip_qps of this TrafficLimitConfig.
        :rtype: int
        """
        return self._per_source_ip_qps

    @per_source_ip_qps.setter
    def per_source_ip_qps(self, per_source_ip_qps):
        """Sets the per_source_ip_qps of this TrafficLimitConfig.

        对转发策略单源进行限速。 quic监听器下转发策略不支持配置单源限速，指定该字段时，赋值可以为0或者为null 取值： 0-100000s。0表示不限速，如果qps不为0，per_ip_qps需要小于qps。

        :param per_source_ip_qps: The per_source_ip_qps of this TrafficLimitConfig.
        :type per_source_ip_qps: int
        """
        self._per_source_ip_qps = per_source_ip_qps

    @property
    def burst(self):
        """Gets the burst of this TrafficLimitConfig.

        对转发策略单源进行限速。取值： 0-100000s。当qps超限的时候，不返回503，支持允许局部突增burst大小的请求。

        :return: The burst of this TrafficLimitConfig.
        :rtype: int
        """
        return self._burst

    @burst.setter
    def burst(self, burst):
        """Sets the burst of this TrafficLimitConfig.

        对转发策略单源进行限速。取值： 0-100000s。当qps超限的时候，不返回503，支持允许局部突增burst大小的请求。

        :param burst: The burst of this TrafficLimitConfig.
        :type burst: int
        """
        self._burst = burst

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrafficLimitConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
